ConfigEnvVarLoader
==================

.. currentmodule:: pconfig.loaders
.. autoclass:: ConfigEnvVarLoader
  :exclude-members: order
  :members:
  :show-inheritance:

  .. attribute:: order
    :type: int
    :value: -∞

    The order in which loaders will be called. Biggest first.


